==> OpenPatricianDisplay-0.4.0-sources.jar: ch/sahits/game/graphic/display/gameplay/internal/PolygonInitializerFactory.java <==
package ch.sahits.game.graphic.display.gameplay.internal;

import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * Factory for retrieving the proper scene initializer for the current scene, to setup the polygons.
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 13, 2013
 */
@Component
public class PolygonInitializerFactory {
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);
    @Autowired
    private PortScenePolygonInitializer portSceneInitializer;
    @Autowired
    private MarketScenePolygonInitializer marketSceneInitializer;
    @Autowired
    private ShipyardScenePolygonInitializer shipyardSceneInitializer;
    @Autowired
    private TavernScenePolygonInitializer tavernSceneInitializer;
    @Autowired
    private CityHallScenePolygonInitializer cityHallSceneInitializer;
    @Autowired
    private LoanerScenePolygonInitializer loanerSceneInitializer;


    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    public ScenePolygonInitialzer getScenePolygonInitializer() {
        switch (currentScene.get()) {
            case PORT:
                return portSceneInitializer;
            case MARKET:
                return marketSceneInitializer;
            case SHIPYARD:
                return shipyardSceneInitializer;
            case TAVERN:
                return tavernSceneInitializer;
            case CITY_HALL:
                return cityHallSceneInitializer;
            case LOANER:
                return loanerSceneInitializer;
            default:
                throw new IllegalStateException("Unsupported scene: "+currentScene.get());
        }
    }

}

==> OpenPatricianDisplay-0.8.0-sources.jar: ch/sahits/game/graphic/display/gameplay/internal/PolygonInitializerFactory.java <==
package ch.sahits.game.graphic.display.gameplay.internal;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.DependentInitialisation;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.ObjectPropertyType;
import ch.sahits.game.openpatrician.util.StartNewGameBean;
import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * Factory for retrieving the proper scene initializer for the current scene, to setup the polygons.
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 13, 2013
 */
@Component
@Lazy
@DependentInitialisation(StartNewGameBean.class)
@ClassCategory(EClassCategory.SINGLETON_BEAN)
public class PolygonInitializerFactory {
    @ObjectPropertyType(EScene.class)
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);
    @Autowired
    private PortScenePolygonInitializer portSceneInitializer;
    @Autowired
    private MarketScenePolygonInitializer marketSceneInitializer;
    @Autowired
    private ShipyardScenePolygonInitializer shipyardSceneInitializer;
    @Autowired
    private TavernScenePolygonInitializer tavernSceneInitializer;
    @Autowired
    private CityHallScenePolygonInitializer cityHallSceneInitializer;
    @Autowired
    private LoanerScenePolygonInitializer loanerSceneInitializer;
    @Autowired
    private ChurchScenePolygonInitializer churchSceneInitializer;
    @Autowired
    private GuildScenePolygonInitializer guildSceneInitializer;


    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    public ScenePolygonInitialzer getScenePolygonInitializer() {
        switch (currentScene.get()) {
            case PORT:
                return portSceneInitializer;
            case MARKET:
                return marketSceneInitializer;
            case SHIPYARD:
                return shipyardSceneInitializer;
            case TAVERN:
                return tavernSceneInitializer;
            case CITY_HALL:
                return cityHallSceneInitializer;
            case LOANER:
                return loanerSceneInitializer;
            case CHURCH:
                 return churchSceneInitializer;
            case GUILD:
                return guildSceneInitializer;
            default:
                throw new IllegalStateException("Unsupported scene: "+currentScene.get());
        }
    }

}
